@@ -464,8 +464,10 @@ class dbus_switchboard_gui (hildon.Program):
     def load_uri_defaults(self):
         print "**Load Uri Defaults**"
         print '@ ' + URIDEFAULTSPATH
+
         self.uri_defaults = {}
         fp = open(URIDEFAULTSPATH)
+
         for line in fp:
             if line.startswith('#'):
                 continue
@@ -493,12 +495,32 @@ class dbus_switchboard_gui (hildon.Program):
             key = line.split('=')[0]
             val = line.split('=')[1].strip()
             self.uri_defaults_base[key] = val
+
     def write_uri_defaults(self):
         fp = open('/tmp/dbsw_uri-defaults.list', 'w')
         fp.flush()
-        for key in self.uri_defaults:
-            s = key + '=' + self.uri_defaults[key] + '\n'
-            fp.write(s)
+
+# qole mod: write out original file, substitute keys where necessary
+
+#       qole mod to make this work: read the file into a list.
+
+        fp2 = open(URIDEFAULTSPATH)
+        self.uri_defaults_file = []
+        for line in fp2:
+          self.uri_defaults_file.append(line)
+        fp2.close()
+
+
+# write the file back out unchanged, except the key pairs
+
+        for line in self.uri_defaults_file:
+
+           if '=' in line:
+             key = line.split('=')[0]
+             line = key + '=' + self.uri_defaults[key] + '\n'
+
+           fp.write(line)
+
         fp.close()
 
 # Pipeline un-sudo since app aleady sudo'ed
